"""
This file provides autocompletions for the ZOS-API and was automatically generated.
It should not be edited manually.
"""

from enum import Enum

__all__ = ("XYSymmetricField", "YSymmetricField")

class XYSymmetricField(Enum):
    All = 0
    Zero = 1
    YPositive70Percent = 2
    YNegative70Percent = 3
    YPositive100Percent = 4
    YNegative100Percent = 5
    XPositive70Percent = 6
    XNegative70Percent = 7
    XPositive100Percent = 8
    XNegative100Percent = 9

class YSymmetricField(Enum):
    All = 0
    Zero = 1
    Positive70Percent = 2
    Negative70Percent = 3
    Positive100Percent = 4
    Negative100Percent = 5
